#here can to help you made other data type
def to_str(num):
    num = float(num)
    return str(num)

def to_list(*num):
    number = []
    for i in num:
        i = float(i)
        number.append(str(i))
    return [i for i in number]

def to_dictionary(*num):
    dic = {}
    number = [i for i in num]
    for i in range(len(number)):
        key,num = number[i]
        dic[key] = num
    return dic

def back_int(string):
    try:
        return int(string)
    except:
        raise TypeError("The data type can't int")

if __name__ == '__main__':
    print(to_dictionary(('我是帅逼',6666666666666),('我是傻逼',38)))
    print(to_str(123.123))
    print(to_list(1,1,1,1,1))


import setuptools

with open("README.md", "r") as fh:
  long_description = fh.read()

setuptools.setup(
  name="intting",
  version="0.1.2",
  author="zjy_090820",
  author_email="a1234567890001919@outlook.com",
  description="easy to user int (beta)",
  url="https://pypi.org",
  packages=setuptools.find_packages(),
  classifiers=[
  "Programming Language :: Python :: 3",
  "License :: OSI Approved :: MIT License",
  "Operating System :: OS Independent",
  ],
)


def calculate(num1,num2,operating = 'addition',mode = 'int',roundTo = 0):
    # operating has 3 parameter:'int'/'float'/'round'
    # calculate has operating mode,is'addition''add''+'/'subtraction''sub''-'/'multiplication''mul''*'
    if operating == 'addition' or operating == 'add' or operating == '+':
        if mode == 'int':
            return num1 + num2
        elif mode == 'float':
            num1 = float(num1)
            num2 = float(num2)
            return num1 + num2
        elif mode == 'round':
            return round((num1 + num2),roundTo)
    elif operating == 'subtraction' or operating == 'sub' or operating == '-':
        if mode == 'int':
            return num1 - num2
        elif mode == 'float':
            num1 = float(num1)
            num2 = float(num2)
            return num1 - num2
        elif mode == 'round':
            return round((num1 - num2),roundTo)
    elif operating == 'multiplication' or operating == 'mul' or operating == '*':
        if mode == 'int':
            return num1 * num2
        elif mode == 'float':
            num1 = float(num1)
            num2 = float(num2)
            return num1 * num2
        elif mode == 'round':
            return round((num1 * num2),roundTo)
    elif operating == 'division' or operating == 'div' or operating == '/':
        if mode == 'int':
            return num1 / num2
        elif mode == 'float':
            num1 = float(num1)
            num2 = float(num2)
            return num1 / num2
        elif mode == 'round':
            return round((num1 / num2),roundTo)

def count(List):
    string = ''
    for i in List:
        string = '{}{}'.format(string,i)
    return len(string)

def add_at(num1,num2,idx):
    end_num = str(num1)
    add_num = str(num2)
    end_num_list = end_num.split('')
    end_num_list.insert(idx,add_num)
    return int(''.join(end_num_list))

def text_int(text):
    try:
        int(text)
    except:
        return False
    else:
        return True

def copyright():
    print('It is zjy self having')


